@@ -31,7 +31,7 @@
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
 
-#include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-utils.h>
@@ -499,7 +499,7 @@ empathy_individual_chat_menu_item_activated (GtkMenuItem *item,
 {
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
-  empathy_dispatcher_chat_with_contact (contact, gtk_get_current_event_time ());
+  empathy_chat_with_contact (contact, empathy_get_current_action_time ());
 }
 
 GtkWidget *
@@ -543,7 +543,7 @@ empathy_individual_audio_call_menu_item_activated (GtkMenuItem *item,
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
   empathy_call_new_with_streams (contact, TRUE, FALSE,
-      gtk_get_current_event_time ());
+      empathy_get_current_action_time ());
 }
 
 GtkWidget *
@@ -585,7 +585,7 @@ empathy_individual_video_call_menu_item_activated (GtkMenuItem *item,
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
   empathy_call_new_with_streams (contact, TRUE, TRUE,
-      gtk_get_current_event_time ());
+      empathy_get_current_action_time ());
 }
 
 GtkWidget *
@@ -750,7 +750,8 @@ static void
 favourite_menu_item_toggled_cb (GtkCheckMenuItem *item,
   FolksIndividual *individual)
 {
-  folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual),
+  folks_favourite_details_set_is_favourite (
+      FOLKS_FAVOURITE_DETAILS (individual),
       gtk_check_menu_item_get_active (item));
 }
 
@@ -762,7 +763,8 @@ empathy_individual_favourite_menu_item_new (FolksIndividual *individual)
   item = gtk_check_menu_item_new_with_label (_("Favorite"));
 
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-      folks_favouritable_get_is_favourite (FOLKS_FAVOURITABLE (individual)));
+      folks_favourite_details_get_is_favourite (
+          FOLKS_FAVOURITE_DETAILS (individual)));
 
   g_signal_connect (item, "toggled",
       G_CALLBACK (favourite_menu_item_toggled_cb), individual);
