@@ -186,12 +186,9 @@ persona_set_active (EmpathyPersonaStore *self,
     gboolean active,
     gboolean set_changed)
 {
-  EmpathyPersonaStorePriv *priv;
   GtkTreePath *path;
   GtkTreeIter iter;
 
-  priv = GET_PRIV (self);
-
   path = find_persona (self, persona);
   if (path == NULL)
     return;
@@ -535,6 +532,11 @@ individual_personas_changed_cb (GObject *object,
 {
   GList *l;
 
+  /* One of the personas' row references might hold the last reference to the
+   * PersonaStore, so we need to keep a reference ourselves so we don't get
+   * finalised. */
+  g_object_ref (self);
+
   /* Remove the old personas. */
   for (l = removed; l != NULL; l = l->next)
     remove_persona_and_disconnect (self, FOLKS_PERSONA (l->data));
@@ -542,6 +544,8 @@ individual_personas_changed_cb (GObject *object,
   /* Add each of the new personas to the tree model */
   for (l = added; l != NULL; l = l->next)
     add_persona_and_connect (self, FOLKS_PERSONA (l->data));
+
+  g_object_unref (self);
 }
 
 static gint
@@ -581,14 +585,14 @@ sort_personas (FolksPersona *persona_a,
 
   /* protocol */
   ret_val = strcmp (tp_account_get_protocol (account_a),
-        tp_account_get_protocol (account_a));
+        tp_account_get_protocol (account_b));
 
   if (ret_val != 0)
     goto out;
 
   /* account ID */
   ret_val = strcmp (tp_proxy_get_object_path (account_a),
-        tp_proxy_get_object_path (account_a));
+        tp_proxy_get_object_path (account_b));
 
 out:
   return ret_val;
