@@ -49,7 +49,6 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-ft-factory.h>
 
 void
@@ -231,8 +230,8 @@ empathy_icon_name_for_individual (FolksIndividual *individual)
 	TpConnectionPresenceType presence;
 
 	folks_presence =
-	    folks_presence_owner_get_presence_type (
-	        FOLKS_PRESENCE_OWNER (individual));
+	    folks_presence_details_get_presence_type (
+	        FOLKS_PRESENCE_DETAILS (individual));
 	presence = empathy_folks_presence_type_to_tp (folks_presence);
 
 	return empathy_icon_name_for_presence (presence);
@@ -406,11 +405,10 @@ empathy_avatar_pixbuf_roundify (GdkPixbuf *pixbuf)
 static gboolean
 empathy_gdk_pixbuf_is_opaque (GdkPixbuf *pixbuf)
 {
-	gint width, height, rowstride, i;
+	gint height, rowstride, i;
 	guchar *pixels;
 	guchar *row;
 
-	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
 	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
 	pixels = gdk_pixbuf_get_pixels (pixbuf);
@@ -633,7 +631,7 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 
 	avatar_file =
-		folks_avatar_owner_get_avatar (FOLKS_AVATAR_OWNER (individual));
+		folks_avatar_details_get_avatar (FOLKS_AVATAR_DETAILS (individual));
 	if (avatar_file == NULL)
 		goto out;
 
@@ -1996,3 +1994,9 @@ empathy_context_menu_new (GtkWidget *attach_to)
 
 	return menu;
 }
+
+gint64
+empathy_get_current_action_time (void)
+{
+  return (tp_user_action_time_from_x11 (gtk_get_current_event_time ()));
+}
