@@ -1335,8 +1335,9 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 				  G_CALLBACK (chat_window_notification_closed_cb), window, 0);
 
 		if (has_x_canonical_append) {
+			/* We have to set a not empty string to keep libnotify happy */
 			notify_notification_set_hint_string (notification,
-				EMPATHY_NOTIFY_MANAGER_CAP_X_CANONICAL_APPEND, "");
+				EMPATHY_NOTIFY_MANAGER_CAP_X_CANONICAL_APPEND, "1");
 		}
 	}
 
@@ -1451,7 +1452,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 		chatroom = empathy_chatroom_manager_find (priv->chatroom_manager,
 							  account, room);
 
-		if (empathy_chatroom_is_always_urgent (chatroom)) {
+		if (chatroom != NULL && empathy_chatroom_is_always_urgent (chatroom)) {
 			needs_urgency = TRUE;
 		} else {
 			needs_urgency = empathy_message_should_highlight (message);
@@ -1785,7 +1786,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 
 		if (!chat) {
 			empathy_chat_with_contact_id (
-				account, contact_id, gtk_get_current_event_time ());
+				account, contact_id, empathy_get_current_action_time ());
 
 			g_strfreev (strv);
 			return;
@@ -2385,7 +2386,11 @@ empathy_chat_window_present_chat (EmpathyChat *chat,
 		window = empathy_chat_window_get_default (empathy_chat_is_room (chat));
 		if (!window) {
 			window = empathy_chat_window_new ();
-			gtk_widget_show_all (GET_PRIV (window)->dialog);
+
+			/* we want to display the newly created window even if we don't present
+			* it */
+			priv = GET_PRIV (window);
+			gtk_widget_show (priv->dialog);
 		}
 
 		empathy_chat_window_add_chat (window, chat);
